CodeMirror: HTML mixed-mode demonstration

This is a simple demonstration of the HTML mixed-mode indentation module for CodeMirror. Script tags use the JS parser, style tags use the CSS parser.

<html> <head> <title>HTML Example</title> <script type="text/javascript"> function foo(bar, baz) { alert("quux"); return bar + baz + 1; } </script> <style type="text/css"> div.border { border: 1px solid black; padding: 3px; } #foo code { font-family: courier, monospace; font-size: 80%; color: #448888; } </style> </head> <body> <p>Duh</p> </body> </html>